import React, { ReactNode } from "react";
import styled from "styled-components";
import { px2rem } from "../utils/getFontSize";
import { device } from "../utils/mediaSizes";

interface IContainer {
  children: ReactNode;
  padding?: number;
  paddingLeft?: number;
  paddingRight?: number;
  paddingBottom?: number;
  backgroundColor?: string;
  backgroundImage?: string;
  backgroundImagePosition?: string;
  backgroundImageSize?: string;
  color?: string;
  width?: string;
  height?: string;
  boxShadow?: boolean;
  fontFamily?: string;
  center?: boolean;
  centerHorizontal?: boolean;
  centerVertical?: boolean;
  borderRadius?: number;
  border?: "small" | "medium" | "large";
  borderColor?: string;
  horizontalCenterMobile?: boolean;
  maxWidth?: string;
  minHeight?: string;
  mobileWidth?: string;
  alignBottom?: boolean;
  alignRight?: boolean;
  flexRow?: boolean;
  textAlign?: string;
  cursorPointer?: boolean;
}

const StyledContainer = styled.div<IContainer>`
  display: flex;
  flex-direction: column;
  ${({ padding }) => padding && `padding: ${px2rem(padding)};`}
  ${({ flexRow }) => flexRow && "flex-direction: row;"}
  ${({ paddingLeft }) => paddingLeft && `padding-left: ${px2rem(paddingLeft)};`}
  ${({ paddingBottom }) =>
    paddingBottom && `padding-bottom: ${px2rem(paddingBottom)};`}
  ${({ paddingRight }) =>
    paddingRight && `padding-right: ${px2rem(paddingRight)};`}
  ${({ backgroundColor }) =>
    backgroundColor && `background-color: ${backgroundColor};`}
    ${({ backgroundImage }) =>
    backgroundImage &&
    `
    background-image: url(${backgroundImage});
    background-repeat: no-repeat;
    background-position: 100% 100%;
  `}
   ${({ backgroundImagePosition }) =>
    backgroundImagePosition &&
    `
    background-position: ${backgroundImagePosition};
  `}
   ${({ backgroundImageSize }) =>
    backgroundImageSize &&
    `
    background-size: ${backgroundImageSize};
  `}

  ${({ color }) => color && `color: ${color};`}
  ${({ width }) => width && `width: ${width};`}
  ${({ mobileWidth }) => mobileWidth && `width: ${mobileWidth};`};
  ${({ height }) => height && `height: ${height};`}
  ${({ boxShadow }) => boxShadow && `box-shadow: -2px 5px 15px -2px #999;`}
  ${({ fontFamily }) => fontFamily && `font-family: ${fontFamily};`}
  ${({ center }) =>
    center && `display: flex; justify-content: center; align-items: center;`}
  ${({ centerHorizontal }) =>
    centerHorizontal && `display: flex; justify-content: center;`}
  ${({ centerVertical }) =>
    centerVertical && `display: flex; align-items: center;`}
  ${({ border }) => border === "small" && `border: solid 1px;`}
  ${({ border }) => border === "medium" && `border: solid 5px;`}
  ${({ border }) => border === "large" && `border: solid 10px;`}
  ${({ borderRadius }) => borderRadius && `border-radius: ${borderRadius}px;`}
  ${({ borderColor }) => borderColor && `border-color: ${borderColor};`}
  ${({ horizontalCenterMobile }) =>
    horizontalCenterMobile && `display: flex; justify-content: center;`}
  ${({ maxWidth }) => maxWidth && `max-width: ${maxWidth};`}
  ${({ minHeight }) => minHeight && `min-height: ${minHeight};`}
  ${({ alignBottom }) => alignBottom && `margin-top: auto;`}
  ${({ alignRight }) => alignRight && `align-items: flex-end;`}
  ${({ textAlign }) => textAlign && `text-align: ${textAlign};`}
  ${({ cursorPointer }) => cursorPointer && `cursor: pointer;`}
  @media ${device.tablet} {
    ${({ width }) => width && `width: ${width};`}
  }
  @media ${device.mobileL} {
    ${({ horizontalCenterMobile }) =>
      horizontalCenterMobile && `display: flex; justify-content: initial;`};
    ${({ width }) => width && `width: ${width};`}
  }
`;

export const Container = ({
  padding,
  paddingLeft,
  paddingRight,
  paddingBottom,
  children,
  backgroundColor,
  backgroundImage,
  backgroundImagePosition,
  backgroundImageSize,
  color,
  width,
  height,
  boxShadow,
  fontFamily,
  center,
  centerHorizontal,
  centerVertical,
  borderRadius,
  border,
  borderColor,
  horizontalCenterMobile,
  minHeight,
  maxWidth,
  mobileWidth,
  alignBottom,
  alignRight,
  flexRow,
  textAlign,
  cursorPointer,
}: IContainer) => (
  <StyledContainer
    padding={padding}
    paddingLeft={paddingLeft}
    paddingRight={paddingRight}
    paddingBottom={paddingBottom}
    backgroundColor={backgroundColor}
    backgroundImage={backgroundImage}
    backgroundImagePosition={backgroundImagePosition}
    backgroundImageSize={backgroundImageSize}
    color={color}
    width={width}
    height={height}
    boxShadow={boxShadow}
    fontFamily={fontFamily}
    center={center}
    centerHorizontal={centerHorizontal}
    centerVertical={centerVertical}
    border={border}
    borderRadius={borderRadius}
    borderColor={borderColor}
    horizontalCenterMobile={horizontalCenterMobile}
    minHeight={minHeight}
    maxWidth={maxWidth}
    mobileWidth={mobileWidth}
    alignBottom={alignBottom}
    alignRight={alignRight}
    flexRow={flexRow}
    textAlign={textAlign}
    cursorPointer={cursorPointer}
    data-testid="container"
  >
    {children}
  </StyledContainer>
);
