import React, { ReactNode } from "react";
import styled from "styled-components";
import { px2rem } from "../../utils/getFontSize";

export interface IStyledGrid {
  columns?: number;
  columnsMobile?: number;
  columnsTablet?: number;
  rows?: number;
  rowGap?: number;
  columnGap?: number;
}
export interface IGrid extends IStyledGrid {
  dataTestId?: string;
  children: ReactNode;
}

const StyledGrid = styled.div<IStyledGrid>`
  display: grid;
  grid-template-columns: repeat(${({ columns }) => columns}, 1fr);
  grid-column-gap: 12px;
  grid-row-gap: 12px;
  ${({ rows }) => rows && `grid-template-rows: repeat(${rows}, 1fr);`}
  ${({ rowGap }) => rowGap && `grid-row-gap: ${px2rem(rowGap)}};`}
  ${({ columnGap }) => columnGap && `grid-column-gap: ${px2rem(columnGap)}};`}
  @media (max-width: 996px) {
    ${({ columnsTablet }) =>
      columnsTablet && `grid-template-columns: repeat(${columnsTablet}, 1fr);`}
  }
  @media (max-width: 600px) {
    ${({ columnsMobile }) =>
      columnsMobile && `grid-template-columns: repeat(${columnsMobile}, 1fr);`}
  }
`;

export const UiStartGrid = ({
  dataTestId,
  children,
  columns,
  columnsMobile,
  columnsTablet,
  rows,
  rowGap,
  columnGap,
}: IGrid) => (
  <StyledGrid
    data-testid={dataTestId}
    columns={columns}
    columnsMobile={columnsMobile}
    columnsTablet={columnsTablet}
    rows={rows}
    rowGap={rowGap}
    columnGap={columnGap}
  >
    {children}
  </StyledGrid>
);
