import React from "react";
import styled from "styled-components";
import { Container } from "../../Atoms/Container";
import { UIHeader } from "../../Atoms/Header";
import { Spacer } from "../../Atoms/Spacer";
import { NavBar } from "../../Organisms/NavBar/NavBar";

const StyledElsaHomePage = styled.div``;

export const colors = {
  cyan: "#5ac1d2",
  purple: "#974b97",
  white: "#fff",
  darkGray: "#333",
  lightGray: "whitesmoke",
  black: "#000",
};

const menuItems = [
  {
    link: "/",
    label: "Home",
  },
  {
    link: "/donate",
    label: "Donate",
  },
  {
    link: "",
    label: "Get Involved",
    subMenu: [
      {
        link: "/school",
        label: "School",
      },
      {
        link: "/business",
        label: "Business",
      },
      {
        link: "/volunteer",
        label: "Volunteer",
      },
    ],
  },
  {
    link: "/events",
    label: "Our Events",
  },
  {
    link: "/success",
    label: "Success Stories",
  },
  {
    link: "/contact",
    label: "Contact Us",
  },
  {
    link: "/about",
    label: "About Us",
  },
  {
    link: "/newsletter",
    label: "Newsletter",
  },
];

export const ElsaHomePage = () => (
  <StyledElsaHomePage>
    <Container width="100%" flexRow height="80px" centerVertical>
      <Container>
        <a href="/">
          <img
            src="https://elsa-website-assets.s3.amazonaws.com/elsa-logo.png"
            alt="Elsa Logo"
            style={{ width: "auto", height: "80px" }}
          />
        </a>
      </Container>
      <Container
        width="fill-available"
        alignRight
        alignBottom
        paddingRight={16}
      >
        <NavBar
          linkColor={colors.purple}
          linkFontSize={24}
          subLinkFontSize={20}
          hoverColor={colors.cyan}
          menuItems={menuItems}
          mobileBreakpoint={1400}
        />
      </Container>
    </Container>
    <Container
      center
      width="100%"
      height="350px"
      backgroundImage="https://stunning-cat-2fff77.netlify.app/static/997326ff9dd5af76ce7624f0040c3f84/5f9b5/slider-img-1.webp"
      backgroundImageSize="cover"
      backgroundImagePosition="0 20%"
    >
      <Container
        color="white"
        backgroundColor={colors.cyan}
        padding={16}
        textAlign="center"
      >
        <UIHeader level={1} fontSize={40}>
          HELPING YOUNG PEOPLE REACH THEIR POTENTIAL
        </UIHeader>
      </Container>
    </Container>
    <Container center color={colors.cyan} padding={16}>
      <Spacer height={16} />
      <Container center maxWidth="1200px" textAlign="center">
        <UIHeader level={2} fontSize={26}>
          Founded in 2015, ELSA Next Generation is an award-winning non-profit
          organisation providing targeted and transformational educational
          programmes to young people. Over 20,000 young people have been
          supported so far working with over 50 business partners.
        </UIHeader>
      </Container>
      <Spacer height={16} />
      <Container center maxWidth="1200px" textAlign="center">
        <UIHeader level={2} fontSize={26} color={colors.purple}>
          Our vision: We believe every young person regardless of background or
          ability deserves the opportunity to develop into a confident and
          positive member of their community. ELSA offers opportunities, hope
          and support through bespoke educational workshops and programmes.
        </UIHeader>
      </Container>
      <Spacer height={16} />
      <Container center maxWidth="1200px" textAlign="center">
        <UIHeader level={2} fontSize={26}>
          Our mission: Is to support and develop every student who we work with,
          bridging the gap between education and employability, our unique
          programmes help young people learn essential personal development
          skills and understand the qualities and skills required by employers
          today.
        </UIHeader>
      </Container>
      <Spacer height={32} />
      <Container center maxWidth="1200px" textAlign="center">
        <UIHeader level={2} fontSize={26} color={colors.purple}>
          We inspire, encourage and empower young people to think and believe
          they all have the chance of a successful future.
        </UIHeader>
      </Container>
    </Container>
  </StyledElsaHomePage>
);
